# Generated by Django 4.2.14 on 2024-08-21 19:22

from django.db import migrations, models


def move_label_select_to_q(apps, schema_editor):
    """
    To keep ZDU, the pulp_label_select field will be moved, but not deleted during this
    migration. Old tasks will still be able to access the field and new tasks will use the new
    q_select field. Any new UpstreamPulps will only use q_select (label_select is being removed
    from the serializer), so on the next breaking change release we can add a migration to remove
    the pulp_label_select field.
    """
    UpstreamPulp = apps.get_model("core", "UpstreamPulp")
    batch = []
    for upstream in UpstreamPulp.objects.filter(pulp_label_select__isnull=False).iterator():
        if upstream.pulp_label_select:
            upstream.q_select = f"pulp_label_select={upstream.pulp_label_select!r}"
            batch.append(upstream)
            if len(batch) >= 500:
                UpstreamPulp.objects.bulk_update(batch, ["q_select"])
                batch = []
    if batch:
        UpstreamPulp.objects.bulk_update(batch, ["q_select"])


class Migration(migrations.Migration):

    dependencies = [
        ("core", "0122_record_last_replication_timestamp"),
    ]

    operations = [
        migrations.AddField(
            model_name="upstreampulp",
            name="q_select",
            field=models.TextField(null=True),
        ),
        migrations.RunPython(
            code=move_label_select_to_q,
            reverse_code=migrations.RunPython.noop,
            elidable=True,
        ),
    ]
